### Description

Annotations, notes scribbled in the margins or digitally overlain, spin out from a source text, adding layers of meaning, interpretations, references, and associations. As an experimental practice, annotating has the potential to redefine the lines between writers and readers, sources and exegesis, and reviewers and reviewees.  

### Full description

Web-based annotations of digital books enrich and add meaning to a scholarly text through overlays and filters that sit on top of the text—often allowing direct referencing of granular elements (specific words, segments, paragraphs)—in order to show additional textual or multimodal commentary and feedback. Annotations—in short, a form of readerly or writerly interaction that consists of notes (in any medium) added to texts (of any medium)—already have a long history in a print and manuscript context (e.g. marginalia, errata, rubrics), but the immediacy of two-way discussion between users is a notable feature of digital open annotations. Annotation can serve many purposes, "it can provide information, share commentary, spark conversation, express power, and also aid learning" [(Kalir and Garcia, 2021)](https://mitpressonpubpub.mitpress.mit.edu/annotation). Adding contextual references, such as metadata, can enrich the underlying text, for example by creating a semantic network that sets a given publication in relation to other publications (hyperlinking, linked open data). This can facilitate a more "seamless integration of research materials and scholarly analysis" [(McPherson, 2010)](https://doi.org/10.3998/3336451.0013.208). Beyond human generated annotations, there are also opportunities to enhance content through auto-generated annotations, adding info about identifiers, controlled vocabulary, or recommendations. Annotations can also be enhanced themselves, by making them "searchable by tags that make it possible to identify the type of annotation or its content" ([Bertino & Staines, 2019](https://doi.org/10.3390/publications7020041); [Lange, 2020](https://doi.org/10.1515/9783110689112-011)) and because of digital technologies readers are now able to export, share, and preserve their annotations for a range of audiences.

### Experimental uses

While pre-digital annotation has mostly been a private practice [(Humphreys et al., 2018)](https://doi.org/10.3998/3336451.0021.102), digital tools enable the ongoing and shared open annotation of texts, potentially blurring divisions between text and annotation, and author, editor, reviewer, and reader. This speaks of the participatory approach to annotating content and annotations potential to undermine traditional notions of proprietary authorship and authorial control over open content. Annotation also provides opportunity to "socialize the process of knowledge creation" by extending the "collaborative spirit" from authorship out to review and revision, and from there to create knowledge communities ([Montgomery et al., 2018](https://doi.org/10.21428/99f89a34); [Kalir & Garcia, 2021](https://mitpressonpubpub.mitpress.mit.edu/annotation)). Open annotation can thus simultaneously foreground social processes of authorship while also questioning the very nature of authorial authority. It has the ability to enrich a document through its ability to 'interweave' itself with the other voices in a project, thus presenting a textured, multi-perspective publication in one document while also posing questions about where the document actually begins and ends [(Adema, 2018)](http://dx.doi.org/10.17613/M6DN3ZV67). Annotation therefore points to a level of liquidity and intertextuality within a publication that disrupts what it means to have a fixed and final publication.

Increasingly publishers are experimenting with annotation features either on top of their open book collections or on specific open titles, and annotations (either in the authoring or the reading environment) are also becoming a standard feature of long-form experimental publishing platforms, from CommentPress to Manifold, Scalar, and PubPub. MIT Press has accommodated annotation and conversation around some of the books in its [MIT Press Open](https://mitpressonpubpub.mitpress.mit.edu/) collection. This includes books in its [Works in Progress programme](https://wip.mitpress.mit.edu/) released on the PubPub platform for pre- or post-publication feedback, designed for works in early stages of their development that could benefit from community feedback to further develop ideas. Titles include [*Open Knowledge Institutions*](https://wip.mitpress.mit.edu/oki), a book co-authored by 13 scholars as part of a 'Book Sprint', but the press has also released books for formal assessment via their Community Review programme, including the manuscripts for [*Data Feminisms*](https://mitpressonpubpub.mitpress.mit.edu/data-feminism) and [*Annotation*](https://mitpressonpubpub.mitpress.mit.edu/annotation) that were posted for public comment prior to entering the publication process.

Open Humanities Press have been exploring the affordances of annotation as part of their focus on the rewriting of books in their back catalogue. With their *Combinatorial Books: Gathering Flowers* book series, they are encouraging readers/writers to actively reuse existing open access books. They have developed a publishing workflow that enables the creation of new combinatorial books out of existing OHP books that are openly licensed for reuse. For the first book in this series the authors collaboratively annotated OHP’s [*The Chernobyl Herbarium* online PDF](https://openhumanitiespress.org/books/download/Marder-Tondeur_2016_The-Chernobyl-Herbarium.pdf) with the aid of the hypothes.is plugin. Tagging and grouping their annotations the authors developed a tentative table of contents for their book-length rewriting, which they further worked out in pads and other collaborative writing environments. The published book will use the PubPub annotation function to link back again to the sections in *The Chernobyl Herbarium* it responds to. In this sense open annotation has the potential to enable more engagement with existing open books and to promote conversation across scholarly monographs [(Bertino & Staines, 2019)](https://doi.org/10.3390/publications7020041).

### Considerations

One important consideration is the power relations that determine who can and does write annotations and who can’t and doesn't (who gets to annotate), "is bound by social norms, cultural practices, and enforced policies", which need to be heeded when we think about how we can cultivate participation and interaction around texts, especially within a scholarly communications context [(Kalir and Garcia, 2021)](https://mitpressonpubpub.mitpress.mit.edu/annotation). This might explain why, notwithstanding several trials in the humanities, annotation as a form of public discourse has not been a resounding success. The culture of academia might be to blame here, with "fears about being ‘scooped’, about blowback, about domineering commenters, and lack of time coalesce to result in extremely poor participation in this emerging form of discourse" [(Skains, 2020](https://doi.org/10.1177/1354856519831988). Time, effort, and accessibility become barriers to participation in this form of academic engagement, especially as annotations usually cannot be cited, meaning that in the scholarly reward and reputation system "they offer no verifiable benefit to the contributor in either cultural capital or actual capital" ([Skains, 2020](https://doi.org/10.1177/1354856519831988); [Perkel, 2015](https://www.nature.com/articles/528153a)). At the same time, books themselves are perhaps not the best "platforms for interaction" because there is already ubiquitous social media on which publications are shared and discussions around them take place (next to already established print-based environments dedicated to discussing research, e.g., conferences and book reviews). Why would scholars duplicate that effort for specific platforms or on specific publications with more restricted audiences, with limited visibility, and with no benefit to their standing or career ([Faulkes, 2014](https://doi.org/10.1016/j.neuron.2014.03.032); [Skains, 2020](https://doi.org/10.1177/1354856519831988))?

### Further reading

Kalir, R and Garcia, A. (2021). *Annotation*, The MIT Press Essential Knowledge Series (Cambridge, MA: The MIT Press) [https://mitpressonpubpub.mitpress.mit.edu/annotation](https://mitpressonpubpub.mitpress.mit.edu/annotation).

Bertino, A. C., and Staines, Heather (2019). ‘Enabling A Conversation Across Scholarly Monographs through Open Annotation’. *Publications*, 7(2), 41. [https://doi.org/10.3390/publications7020041](https://doi.org/10.3390/publications7020041)

Skains, R. L. (2020). ‘Discourse or gimmick? Digital marginalia in online scholarship,’ *Convergence*, 26(4), 942–955. [https://doi.org/10.1177/1354856519831988](https://doi.org/10.1177/1354856519831988)